@@ -1,14 +1,14 @@
 # -*- coding: utf-8 -*-
 
 # gracie/__init__.py
-# Part of Gracie, an OpenID provider
+# Part of Gracie, an OpenID provider.
 #
-# Copyright © 2007-2008 Ben Finney <ben+python@benfinney.id.au>
+# Copyright © 2007–2010 Ben Finney <ben+python@benfinney.id.au>
 # This is free software; you may copy, modify and/or distribute this work
 # under the terms of the GNU General Public License, version 2 or later.
-# No warranty expressed or implied. See the file LICENSE for details.
+# No warranty expressed or implied. See the file ‘LICENSE.GPL-2’ for details.
 
-""" Gracie - OpenID provider for local accounts
+""" Gracie - OpenID provider for local accounts.
 
     Gracie is an OpenID server (a "provider" in OpenID terminology) that
     serves OpenID identities for the local system PAM accounts. It
