@@ -1,15 +1,15 @@
 # -*- coding: utf-8 -*-
 
 # gracie/httprequest.py
-# Part of Gracie, an OpenID provider
+# Part of Gracie, an OpenID provider.
 #
-# Copyright © 2007-2008 Ben Finney <ben+python@benfinney.id.au>
+# Copyright © 2007–2010 Ben Finney <ben+python@benfinney.id.au>
 # This is free software; you may copy, modify and/or distribute this work
 # under the terms of the GNU General Public License, version 2 or later.
-# No warranty expressed or implied. See the file LICENSE for details.
+# No warranty expressed or implied. See the file ‘LICENSE.GPL-2’ for details.
 
-""" HTTP request handling
-"""
+""" HTTP request handling.
+    """
 
 import BaseHTTPServer
 import logging
